==> superfile-1.1.7.1.tar.gz: superfile-1.1.7.1/website/src/content/docs/list/theme-list.md <==
---
title: Theme list
description: List themes currently owned by superfile
head:
  - tag: title
    content: Theme list | superfile
---

> Sort by A-Z

## Blood

- Theme name: `blood`
- Ported by: https://github.com/charlesrocket
- Original Author: https://github.com/charlesrocket

![](https://github.com/yorukot/superfile/blob/main/asset/theme/blood.png?raw=true)

## Catppuccin

- Theme name: `catppuccin`
- Ported by: https://github.com/AnshumanNeon
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin.png?raw=true)

## Catppuccin Frappe

- Theme name: `catppuccin-frappe`
- Ported by: https://github.com/GV14982
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin-frappe.png?raw=true)

## Catppuccin Latte

- Theme name: `catppuccin-latte`
- Ported by: https://github.com/GV14982
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin-latte.png?raw=true)

## Catppuccin Macchiato

- Theme name: `catppuccin-macchiato`
- Ported by: https://github.com/GV14982
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin-macchiato.png?raw=true)

## Dracula

- Theme name: `dracula`
- Ported by: https://github.com/BeanieBarrow
- Original Author: https://github.com/zenorocha

![](https://github.com/yorukot/superfile/blob/main/asset/theme/dracula.png?raw=true)

## Gruvbox

- Theme name: `gruvbox`
- Ported by: https://github.com/yorukot
- Original Author: https://github.com/morhetz/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/gruvbox.png?raw=true)

## Hacks

- Theme name: `hacks`
- Ported by: https://github.com/charlesrocket
- Original Author: https://github.com/charlesrocket

![](https://github.com/yorukot/superfile/blob/main/asset/theme/hacks.png?raw=true)

## Kaolin

- Theme name: `kaolin`
- Ported by: https://github.com/AnshumqanNeon
- Original Author: https://github.com/ogdenwebb/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/kaolin.png?raw=true)

## Nord

- Theme name: `nord`
- Ported by: https://github.com/ramses-eltany
- Original Author: https://github.com/nordtheme

![](https://github.com/yorukot/superfile/blob/main/asset/theme/nord.png?raw=true)

## OneDark

- Theme name: `onedark`
- Ported by: https://github.com/CommandJoo
- Original Author: https://github.com/one-dark

![](https://github.com/yorukot/superfile/blob/main/asset/theme/onedark.png?raw=true)

## Poimandres

- Theme name: `poimandres`
- Ported by: https://github.com/Myles-J
- Original Author: https://github.com/drcmda/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/poimandres.png?raw=true)

## Rosé Pine

- Theme name: `rose-pine`
- Ported by: https://github.com/pearcidar
- Original Author: https://github.com/rose-pine

![](https://github.com/yorukot/superfile/blob/main/asset/theme/rose-pine.png?raw=true)

## Sugarplum
- Theme name: `sugarplum`
- Ported by: https://github.com/lemonlime0x3C33
- Original Author: https://github.com/lemonlime0x3C33

![](https://github.com/yorukot/superfile/blob/main/asset/theme/sugarplum.png?raw=true)

## Tokyonight

- Theme name: `tokyonight`
- Ported by: https://github.com/pearcidar
- Original Author: https://github.com/enkia/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/tokyonight.png?raw=true)

==> superfile-1.2.1.tar.gz: superfile-1.2.1/website/src/content/docs/list/theme-list.md <==
---
title: Theme list
description: List themes currently owned by superfile
head:
  - tag: title
    content: Theme list | superfile
---

> Sort by A-Z

## Ayu Dark

- Theme name: `ayu-dark`
- Ported by: https://github.com/rustnomicon
- Original Author: https://github.com/ayu-theme/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/ayu-dark.png?raw=true)

## Blood

- Theme name: `blood`
- Ported by: https://github.com/charlesrocket
- Original Author: https://github.com/charlesrocket

![](https://github.com/yorukot/superfile/blob/main/asset/theme/blood.png?raw=true)

## Catppuccin

- Theme name: `catppuccin`
- Ported by: https://github.com/AnshumanNeon
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin.png?raw=true)

## Catppuccin Frappe

- Theme name: `catppuccin-frappe`
- Ported by: https://github.com/GV14982
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin-frappe.png?raw=true)

## Catppuccin Latte

- Theme name: `catppuccin-latte`
- Ported by: https://github.com/GV14982
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin-latte.png?raw=true)

## Catppuccin Macchiato

- Theme name: `catppuccin-macchiato`
- Ported by: https://github.com/GV14982
- Original Author: https://github.com/catppuccin

![](https://github.com/yorukot/superfile/blob/main/asset/theme/catppuccin-macchiato.png?raw=true)

## Dracula

- Theme name: `dracula`
- Ported by: https://github.com/BeanieBarrow
- Original Author: https://github.com/zenorocha

![](https://github.com/yorukot/superfile/blob/main/asset/theme/dracula.png?raw=true)

## Everforest Dark Medium

- Theme name: `everforest-dark-medium`
- Ported by: https://github.com/dotintegral
- Original Author: https://github.com/sainnhe/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/everforest-dark-medium.png?raw=true)

## Gruvbox

- Theme name: `gruvbox`
- Ported by: https://github.com/yorukot
- Original Author: https://github.com/morhetz/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/gruvbox.png?raw=true)

## Hacks

- Theme name: `hacks`
- Ported by: https://github.com/charlesrocket
- Original Author: https://github.com/charlesrocket

![](https://github.com/yorukot/superfile/blob/main/asset/theme/hacks.png?raw=true)

## Kaolin

- Theme name: `kaolin`
- Ported by: https://github.com/AnshumqanNeon
- Original Author: https://github.com/ogdenwebb/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/kaolin.png?raw=true)

## Monokai

- Theme name: `monokai`
- Ported by: https://github.com/CommandJoo
- Original Author: https://github.com/monokai

![](https://github.com/yorukot/superfile/blob/main/asset/theme/monokai.png?raw=true)

## Nord

- Theme name: `nord`
- Ported by: https://github.com/ramses-eltany
- Original Author: https://github.com/nordtheme

![](https://github.com/yorukot/superfile/blob/main/asset/theme/nord.png?raw=true)

## OneDark

- Theme name: `onedark`
- Ported by: https://github.com/CommandJoo
- Original Author: https://github.com/one-dark

![](https://github.com/yorukot/superfile/blob/main/asset/theme/onedark.png?raw=true)

## Poimandres

- Theme name: `poimandres`
- Ported by: https://github.com/Myles-J
- Original Author: https://github.com/drcmda/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/poimandres.png?raw=true)

## Rosé Pine

- Theme name: `rose-pine`
- Ported by: https://github.com/pearcidar
- Original Author: https://github.com/rose-pine

![](https://github.com/yorukot/superfile/blob/main/asset/theme/rose-pine.png?raw=true)

## Sugarplum
- Theme name: `sugarplum`
- Ported by: https://github.com/lemonlime0x3C33
- Original Author: https://github.com/lemonlime0x3C33

![](https://github.com/yorukot/superfile/blob/main/asset/theme/sugarplum.png?raw=true)

## Tokyonight

- Theme name: `tokyonight`
- Ported by: https://github.com/pearcidar
- Original Author: https://github.com/enkia/

![](https://github.com/yorukot/superfile/blob/main/asset/theme/tokyonight.png?raw=true)
